@@ -3,7 +3,7 @@ BEGIN {
   $App::Pocoirc::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $App::Pocoirc::VERSION = '0.29';
+  $App::Pocoirc::VERSION = '0.30';
 }
 
 use strict;
@@ -13,14 +13,12 @@ use warnings FATAL => 'all';
 sub POE::Kernel::USE_SIGCHLD () { return 1 }
 
 use App::Pocoirc::Status;
+use Fcntl qw(O_CREAT O_EXCL O_WRONLY);
 use IO::Handle;
 use POE;
 use POE::Component::IRC::Common qw(irc_to_utf8);
 use POE::Component::Client::DNS;
 use POSIX 'strftime';
-use Module::Pluggable
-    sub_name    => '_available_plugins',
-    search_path => 'POE::Component::IRC::Plugin';
 
 sub new {
     my ($package, %args) = @_;
@@ -31,6 +29,11 @@ sub run {
     my ($self) = @_;
 
     if ($self->{list_plugins}) {
+        require Module::Pluggable;
+        Module::Pluggable->import(
+            sub_name    => '_available_plugins',
+            search_path => 'POE::Component::IRC::Plugin',
+        );
         for my $plugin (sort $self->_available_plugins()) {
             $plugin =~ s/^POE::Component::IRC::Plugin:://;
             print $plugin, "\n";
@@ -57,8 +60,8 @@ sub run {
 
     if (defined $self->{cfg}{pid_file}) {
         my $file = $self->{cfg}{pid_file};
-        die "Pid file already exists. Pocoirc already running?\n" if -e $file;
-        open my $fh, '>', $file or die "Can't create pid file $file: $!\n";
+        sysopen my $fh, $file, O_CREAT|O_EXCL|O_WRONLY
+            or die "Can't create pid file or it already exists. Pocoirc already running?\n";
         print $fh "$$\n";
         close $fh;
     }
